@@ -1,6 +1,7 @@
 /* A program to put stress on a POSIX system (stress).
  *
- * Copyright (C) 2001, 2002, 2003 Amos Waterland <awaterl@yahoo.com>
+ * Copyright (C) 2001,2002,2003,2004,2005
+ * Amos Waterland <apw@rossby.metr.ou.edu>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -37,8 +38,8 @@ static char *global_progname = PACKAGE;
 
 /* Implemention of runtime-selectable severity message printing.  */
 #define dbg if (global_debug >= 3) \
-            fprintf (stdout, "%s: dbug: [%lli] (%d) ", \
-                     global_progname, (long long)getpid(), __LINE__), fprintf
+            fprintf (stdout, "%s: dbug: [%lli] ", \
+                     global_progname, (long long)getpid()), fprintf
 #define out if (global_debug >= 2) \
             fprintf (stdout, "%s: info: [%lli] ", \
                      global_progname, (long long)getpid()), fprintf
@@ -257,7 +258,7 @@ main (int argc, char **argv)
           /* Calculate timeout based on current time.  */
           timeout = do_timeout - (currenttime - starttime);
 
-          if (timeout)
+          if (timeout > 0)
             {
               dbg (stdout, "setting timeout to %llis\n", timeout);
             }
@@ -282,7 +283,8 @@ main (int argc, char **argv)
               err (stderr, "fork failed: %s\n", strerror (errno));
               break;
             default:           /* parent */
-              dbg (stdout, "--> hogcpu worker %i forked\n", pid);
+              dbg (stdout, "--> hogcpu worker %lli [%i] forked\n",
+                   do_cpu, pid);
               ++children;
             }
           --do_cpu;
@@ -302,7 +304,7 @@ main (int argc, char **argv)
               err (stderr, "fork failed: %s\n", strerror (errno));
               break;
             default:           /* parent */
-              dbg (stdout, "--> hogio worker %i forked\n", pid);
+              dbg (stdout, "--> hogio worker %lli [%i] forked\n", do_io, pid);
               ++children;
             }
           --do_io;
@@ -322,7 +324,7 @@ main (int argc, char **argv)
               err (stderr, "fork failed: %s\n", strerror (errno));
               break;
             default:           /* parent */
-              dbg (stdout, "--> hogvm worker %i forked\n", pid);
+              dbg (stdout, "--> hogvm worker %lli [%i] forked\n", do_vm, pid);
               ++children;
             }
           --do_vm;
@@ -342,7 +344,8 @@ main (int argc, char **argv)
               err (stderr, "fork failed: %s\n", strerror (errno));
               break;
             default:           /* parent */
-              dbg (stdout, "--> hoghdd worker %i forked\n", pid);
+              dbg (stdout, "--> hoghdd worker %lli [%i] forked\n",
+                   do_hdd, pid);
               ++children;
             }
           --do_hdd;
@@ -459,11 +462,11 @@ hogvm (long long bytes, int hang)
 
   while (1)
     {
+      dbg (stdout, "allocating %lli bytes ...\n", bytes);
       if ((ptr = (char *) malloc (bytes * sizeof (char))))
         {
           for (i = 0; i < bytes; i++)
             ptr[i] = 'Z';       /* Ensure that COW happens.  */
-          dbg (stdout, "hogvm worker malloced %lli bytes\n", i);
         }
       else
         {
@@ -479,6 +482,7 @@ hogvm (long long bytes, int hang)
         }
 
       free (ptr);
+      dbg (stdout, "freed %lli bytes\n", bytes);
     }
 
   return 0;
@@ -493,7 +497,7 @@ hoghdd (long long bytes, int clean)
   char buff[chunk];
 
   /* Initialize buffer with some random ASCII data.  */
-  dbg (stdout, "seeding buffer with random data\n");
+  dbg (stdout, "seeding %d byte buffer with random data\n", chunk);
   for (i = 0; i < chunk - 1; i++)
     {
       j = rand ();
@@ -514,6 +518,7 @@ hoghdd (long long bytes, int clean)
           return 1;
         }
 
+      dbg (stdout, "opened %s for writing %lli bytes\n", name, bytes);
       if (clean == 2)
         {
           dbg (stdout, "unlinking %s\n", name);
@@ -550,7 +555,7 @@ hoghdd (long long bytes, int clean)
         }
       ++j;
 
-      dbg (stdout, "closing %s after writing %lli bytes\n", name, j);
+      dbg (stdout, "closing %s after %lli bytes\n", name, j);
       close (fd);
 
       if (clean == 1)
@@ -702,18 +707,18 @@ usage (int status)
     " -v, --verbose         be verbose\n"
     " -q, --quiet           be quiet\n"
     " -n, --dry-run         show what would have been done\n"
-    " -t, --timeout n       timeout after n seconds\n"
-    "     --backoff n       wait for factor of n us before starting work\n"
-    " -c, --cpu n           spawn n workers spinning on sqrt()\n"
-    " -i, --io n            spawn n workers spinning on sync()\n"
-    " -m, --vm n            spawn n workers spinning on malloc()\n"
-    "     --vm-bytes b      malloc b bytes (default is 256MB)\n"
-    "     --vm-hang         go to sleep after memory allocated\n"
-    " -d, --hdd n           spawn n workers spinning on write()\n"
-    "     --hdd-bytes b     write b bytes of random data (default is 1GB)\n"
-    "     --hdd-noclean     do not unlink file to which random data written\n\n"
+    " -t, --timeout N       timeout after N seconds\n"
+    "     --backoff N       wait factor of N microseconds before work starts\n"
+    " -c, --cpu N           spawn N workers spinning on sqrt()\n"
+    " -i, --io N            spawn N workers spinning on sync()\n"
+    " -m, --vm N            spawn N workers spinning on malloc()/free()\n"
+    "     --vm-bytes B      malloc B bytes per vm worker (default is 256MB)\n"
+    "     --vm-hang         do not free memory allocated by vm workers\n"
+    " -d, --hdd N           spawn N workers spinning on write()/unlink()\n"
+    "     --hdd-bytes B     write B bytes per hdd worker (default is 1GB)\n"
+    "     --hdd-noclean     do not unlink files created by hdd workers\n\n"
     "Example: %s --cpu 8 --io 4 --vm 2 --vm-bytes 128M --timeout 10s\n\n"
-    "Notes: Suffixes may be s,m,h,d,y (time) or k,m,g (size).\n";
+    "Note: Numbers may be suffixed with s,m,h,d,y (time) or B,K,M,G (size).\n";
 
   fprintf (stdout, mesg, global_progname, global_progname, global_progname);
 
